/*
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDeveloper
 */

using System;
using System.IO;
using NUnit.Framework;
using System.Drawing;
using System.Drawing.Drawing2D;

namespace TopCoder.Rules.DependencyMap.View
{   
    /// <summary>
    /// Failure test fixture for SVGRenderer.
    /// </summary>
    [TestFixture]
    public class SVGRendererTests
    {
	
        private String goodFile = ".";
        private SVGRenderer svgr =new SVGRenderer(".");
        private IGraphics svgga = new SVGRenderer(".").GetGraphics(new Dependency("greg"));
        private Font gFont= new Font("monospaced", 12);
        private SolidBrush gBrush = new SolidBrush(Color.Black);
        private PointF gPoint = new PointF(0,0);
	
        /// <summary>
        /// Test constructor with null file.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testCon_Null() 
        {
            new SVGRenderer(null);
        }

        /// <summary>
        /// Test constructor.
        /// </summary>
        [Test]
        public void testCon_Silent() 
        {
            new SVGRenderer(goodFile);
        }
    
        /// <summary>
        /// Test set with null file.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testSet_Null() 
        {
            svgr.Path = (null);
        }
    
        /// <summary>
        /// Test set with null file.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentException))]
        public void testSet_Null2() 
        {
            svgr.Path = "    ";
        }

        /// <summary>
        /// Test set.
        /// </summary>
        [Test]
        public void testSet_Silent() 
        {
            svgr.Path = (goodFile);
        }
        
        /// <summary>
        /// Test draw with null file.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testDraw_Null() 
        {
            svgga.DrawPath(null, null);
        }    
        
        /// <summary>
        /// Test draw with null file.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testDraw_Null2() 
        {
            svgga.DrawPath(new Pen(Color.Black), null);
        }  
        /// <summary>
        /// Test draw with null file.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testDraw_Null3() 
        {
            svgga.DrawPath(null, new GraphicsPath());
        }   

        /// <summary>
        /// Test drawString with nulls.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testDrawS_Null() 
        {
            svgga.DrawString(null, gFont, gBrush, gPoint);
        }   

        /// <summary>
        /// Test drawString with nulls.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testDrawS_Null2() 
        {
            svgga.DrawString("", null, gBrush, gPoint);
        }
        /// <summary>
        /// Test drawString with nulls.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testDrawS_Null3() 
        {
            svgga.DrawString("", gFont, null, gPoint);
        }

    }
}
